@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.118-5-gbfe9302
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.119-6-g3d79331
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 
-our $VERSION = '0.119';
+our $VERSION = '0.120';
 
 use Moose;
 with
@@ -160,8 +160,8 @@ sub configure
 {
     my $self = shift;
 
-    warn '[@Author::ETHER] no "bash" executable found; skipping Run::AfterBuild commands to update .ackrc and .latest symlink', "\n"
-        if not $self->_has_bash;
+    warn '[@Author::ETHER] no "bash" executable found; skipping Run::AfterBuild command to update .ackrc', "\n"
+        if not $INC{'Test/More.pm'} and not $self->_has_bash;
 
     # NOTE! since the working directory has not changed to $zilla->root yet,
     # if running this code via a different mechanism than dzil <command>, file
@@ -257,7 +257,7 @@ sub configure
         [ 'MojibakeTests'       => { ':version' => '0.8' } ],
         [ 'Test::ReportPrereqs' => { ':version' => '0.022', verify_prereqs => 1,
             version_extractor => ( ( any { $_ ne 'MakeMaker' } $self->installer ) ? 'Module::Metadata' : 'ExtUtils::MakeMaker' ),
-            include => [ sort ( qw(autodie JSON::PP YAML), exists $removed{PodCoverageTests} ? () : 'Pod::Coverage' ) ] } ],
+            include => [ sort ( qw(autodie JSON::PP Sub::Name YAML), exists $removed{PodCoverageTests} ? () : 'Pod::Coverage' ) ] } ],
         [ 'Test::Portability'   => { ':version' => '2.000007' } ],
         [ 'Test::CleanNamespaces' => { ':version' => '0.006' } ],
 
@@ -322,7 +322,7 @@ sub configure
         ( $self->_has_bash ?
             [ 'Run::AfterBuild' => '.ackrc' => { ':version' => '0.038', quiet => 1, run => q{bash -c "test -e .ackrc && grep -q -- '--ignore-dir=.latest' .ackrc || echo '--ignore-dir=.latest' >> .ackrc; if [[ `dirname '%d'` != .build ]]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi"} } ]
             : ()),
-        [ 'Run::AfterBuild'     => '.latest' => { ':version' => '0.038', quiet => 1, eval => q!if ('%d' =~ /^%n-[.[:xdigit:]]+$/) { unlink '.latest'; symlink '%d', '.latest'; }! } ],
+        [ 'Run::AfterBuild'     => '.latest' => { ':version' => '0.041', quiet => 1, fatal_errors => 0, eval => q!if ('%d' =~ /^%n-[.[:xdigit:]]+$/) { unlink '.latest'; symlink '%d', '.latest'; }! } ],
 
 
         # Before Release
@@ -407,16 +407,15 @@ sub configure
 
         if (my @modules_for_extra_configs = grep { $plugin->isa($_) or $plugin->does($_) } keys %extra_args)
         {
-            # combine all the relevant configs together, but don't take
-            # :version unless it matches the package exactly
+            # combine all the relevant configs together
             my %configs = map { %{ $extra_args{$_} } } @modules_for_extra_configs;
-            delete $configs{':version'};
 
-            $configs{':version'} = $extra_args{$plugin}{':version'}
-                if exists $extra_args{$plugin} and exists $extra_args{$plugin}{':version'};
-
-            # and add to the payload of this plugin
+            # and add to the payload for this plugin
             @{$payload}{keys %configs} = values %configs;
+
+            # don't keep :version unless it matches the package exactly, but still respect the prereq
+            $plugin_requirements->add_minimum($plugin => delete $configs{':version'})
+                if exists $configs{':version'} and not exists $extra_args{$plugin};
         }
 
         # record develop prereq
@@ -473,7 +472,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.119
+version 0.120
 
 =head1 SYNOPSIS
 
@@ -605,6 +604,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     version_extractor = Module::Metadata
     include = JSON::PP
     include = Pod::Coverage
+    include = Sub::Name
     include = YAML
     include = autodie
     [Test::Portability]
@@ -713,8 +713,9 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     quiet = 1
     run = bash -c "test -e .ackrc && grep -q -- '--ignore-dir=.latest' .ackrc || echo '--ignore-dir=.latest' >> .ackrc; if [[ `dirname '%d'` != .build ]]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi"
     [Run::AfterBuild / .latest]
-    :version = 0.038
+    :version = 0.041
     quiet = 1
+    fatal_errors = 0
     eval = if ('%d' =~ /^%n-[.[:xdigit:]]+$/) { unlink '.latest'; symlink '%d', '.latest'; }
 
 
